@@ -1,4 +1,4 @@
-# Copyright (C) 2021-2022 Greenbone Networks GmbH
+# Copyright (C) 2021-2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -17,9 +17,10 @@
 
 
 import re
+from abc import abstractmethod
 from datetime import date
 from pathlib import Path
-from typing import Dict, List, Optional, Union
+from typing import Dict, List, Optional, Protocol, Union, runtime_checkable
 
 import tomlkit
 
@@ -37,10 +38,29 @@ DEFAULT_CHANGELOG_CONFIG = """commit_types = [
 """
 
 
+@runtime_checkable
+class SupportsStr(Protocol):
+    @abstractmethod
+    def __str__(self) -> str:
+        pass
+
+
 class ChangelogBuilder:
     """
-    Creates Changelog files from conventional commits using the git log,
+    Creates Changelog from conventional commits using the git log
     from the latest tag.
+
+    Example:
+        Create a changelog as a string from the changes between git tags
+        "v1.2.3" and "v2.0.0" using the default config settings.
+
+        .. code-block:: python
+
+            from pontos.changelog import ChangelogBuilder
+
+            builder = ChangelogBuilder(space="my-org", project="my-project)
+            changelog = builder.create_changelog
+                last_version="1.2.3", next_version="2.0.0")
     """
 
     def __init__(
@@ -50,7 +70,17 @@ class ChangelogBuilder:
         project: str,
         git_tag_prefix: Optional[str] = "v",
         config: Optional[Path] = None,
-    ):
+    ) -> None:
+        """
+        Create a new ChangelogBuilder instance.
+
+        Args:
+            space: GitHub space to use (organization or user name).
+            project: GitHub project to create a changelog for
+            git_tag_prefix: Git tag prefix to use when checking for git tags.
+                Default is "v".
+            config: TOML config for conventional commit parsing settings
+        """
         if config:
             if not config.exists():
                 raise ChangelogBuilderError(
@@ -70,8 +100,8 @@ class ChangelogBuilder:
     def create_changelog(
         self,
         *,
-        last_version: Optional[str] = None,
-        next_version: Optional[str] = None,
+        last_version: Optional[SupportsStr] = None,
+        next_version: Optional[SupportsStr] = None,
     ) -> str:
         """
         Create a changelog
@@ -94,8 +124,8 @@ class ChangelogBuilder:
         self,
         output: Union[str, Path],
         *,
-        last_version: Optional[str] = None,
-        next_version: Optional[str] = None,
+        last_version: Optional[SupportsStr] = None,
+        next_version: Optional[SupportsStr] = None,
     ) -> None:
         """
         Create a changelog and write the changelog to a file
@@ -120,7 +150,7 @@ class ChangelogBuilder:
         git = Git()
         return git.rev_list("HEAD", max_parents=0, abbrev_commit=True)[0]
 
-    def _get_git_log(self, last_version: Optional[str]) -> List[str]:
+    def _get_git_log(self, last_version: Optional[SupportsStr]) -> List[str]:
         """Getting the git log for the next version.
 
         Requires the fitting branch to be checked out
@@ -187,8 +217,8 @@ class ChangelogBuilder:
 
     def _build_changelog(
         self,
-        last_version: Optional[str],
-        next_version: Optional[str],
+        last_version: Optional[SupportsStr],
+        next_version: Optional[SupportsStr],
         commit_dict: Dict[str, List[str]],
     ) -> str:
         """
