@@ -1,4 +1,4 @@
-# Copyright (C) 2022 Greenbone Networks GmbH
+# Copyright (C) 2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -17,4 +17,10 @@
 
 from .git import ConfigScope, Git, GitError, MergeStrategy, TagSort
 
-__all__ = ("Git", "GitError", "MergeStrategy", "ConfigScope", "TagSort")
+__all__ = (
+    "MergeStrategy",
+    "ConfigScope",
+    "TagSort",
+    "GitError",
+    "Git",
+)
