@@ -1,4 +1,4 @@
-# Copyright (C) 2022 Greenbone Networks GmbH
+# Copyright (C) 2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -18,6 +18,7 @@
 from typing import Optional, Union
 
 from pontos.github.api.client import GitHubAsyncREST
+from pontos.github.api.helper import JSON_OBJECT
 from pontos.github.models.organization import (
     GitIgnoreTemplate,
     LicenseType,
@@ -46,6 +47,15 @@ class GitHubAsyncRESTRepositories(GitHubAsyncREST):
 
         Returns:
             Information about the repository
+
+        Example:
+            .. code-block:: python
+
+                from pontos.github.api import GitHubAsyncRESTApi
+
+                async with GitHubAsyncRESTApi(token) as api:
+                    repo = await api.repositories.get("foo/bar")
+                    print(repo)
         """
         api = f"/repos/{repo}"
         response = await self._client.get(api)
@@ -62,6 +72,14 @@ class GitHubAsyncRESTRepositories(GitHubAsyncREST):
         Raises:
             HTTPStatusError: A httpx.HTTPStatusError is raised if the request
                 failed.
+
+        Example:
+            .. code-block:: python
+
+                from pontos.github.api import GitHubAsyncRESTApi
+
+                async with GitHubAsyncRESTApi(token) as api:
+                    await api.repositories.delete("foo/bar")
         """
         api = f"/repos/{repo}"
         response = await self._client.delete(api)
@@ -81,7 +99,7 @@ class GitHubAsyncRESTRepositories(GitHubAsyncREST):
         has_downloads: Optional[bool] = True,
         is_template: Optional[bool] = False,
         team_id: Optional[str] = None,
-        auto_init: Optional[str] = False,
+        auto_init: Optional[bool] = False,
         gitignore_template: Optional[Union[GitIgnoreTemplate, str]] = None,
         license_template: Optional[Union[LicenseType, str]] = None,
         allow_squash_merge: Optional[bool] = True,
@@ -185,9 +203,28 @@ class GitHubAsyncRESTRepositories(GitHubAsyncREST):
         Raises:
             HTTPStatusError: A httpx.HTTPStatusError is raised if the request
                 failed.
+
+        Example:
+            .. code-block:: python
+
+                from pontos.github.api import GitHubAsyncRESTApi
+
+                async with GitHubAsyncRESTApi(token) as api:
+                    repo = await api.repositories.create(
+                        "foo/bar",
+                        "baz",
+                        description="A new baz repository",
+                        private=True,
+                        allow_squash_merge=True,
+                        allow_merge_commit=False,
+                        allow_rebase_merge=True,
+                        allow_auto_merge=True,
+                        allow_update_branch=True,
+                        delete_branch_on_merge=True,
+                    )
         """
         api = f"/orgs/{organization}/repos"
-        data = {"name": name}
+        data: JSON_OBJECT = {"name": name}
 
         if description:
             data["description"] = description
@@ -258,10 +295,18 @@ class GitHubAsyncRESTRepositories(GitHubAsyncREST):
         Raises:
             HTTPStatusError: A httpx.HTTPStatusError is raised if the request
                 failed.
+
+        Example:
+            .. code-block:: python
+
+                from pontos.github.api import GitHubAsyncRESTApi
+
+                async with GitHubAsyncRESTApi(token) as api:
+                    await api.repositories.archive("foo/bar")
         """
         api = f"/repos/{repo}"
 
-        data = {"archived": True}
+        data: JSON_OBJECT = {"archived": True}
         response = await self._client.post(api, data=data)
         response.raise_for_status()
 
@@ -374,10 +419,29 @@ class GitHubAsyncRESTRepositories(GitHubAsyncREST):
         Raises:
             HTTPStatusError: A httpx.HTTPStatusError is raised if the request
                 failed.
+
+        Returns:
+            The updated repository
+
+        Example:
+            .. code-block:: python
+
+                from pontos.github.api import GitHubAsyncRESTApi
+
+                async with GitHubAsyncRESTApi(token) as api:
+                    repo = await api.repositories.update(
+                        "foo/bar",
+                        allow_squash_merge=True,
+                        allow_merge_commit=False,
+                        allow_rebase_merge=True,
+                        allow_auto_merge=True,
+                        allow_update_branch=True,
+                        delete_branch_on_merge=True,
+                    )
         """
         api = f"/repos/{repo}"
 
-        data = {}
+        data: JSON_OBJECT = {}
         if name:
             data["name"] = name
         if description:
