@@ -1,4 +1,4 @@
-# Copyright (C) 2022 Greenbone Networks GmbH
+# Copyright (C) 2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -24,6 +24,8 @@ from pathlib import Path
 from types import ModuleType
 from typing import Generator, Union
 
+from httpx import Timeout
+
 from pontos.github.api.api import GitHubAsyncRESTApi
 from pontos.github.script.errors import GitHubScriptError
 from pontos.helper import add_sys_path, ensure_unload_module
@@ -47,7 +49,9 @@ def load_script(
     Example:
         .. code-block:: python
 
-            with load_module("path/to/script.py") as module:
+            from pontos.github.script import load_script
+
+            with load_script("path/to/script.py") as module:
                 module.func()
     """
     path = Path(script)
@@ -70,6 +74,24 @@ def run_github_script_function(
         token: A GitHub token for authentication
         timeout: Timeout for the GitHub requests in seconds
         args: Arguments forwarded to the script function
+
+    Raises:
+        GitHubScriptError: If the module doesn't have a github_script function
+            or if the github_script function is not an async coroutine.
+
+    Returns:
+        The return value of the github_script coroutine
+
+    Example:
+        .. code-block:: python
+
+            from pontos.github.script import (
+                load_script,
+                run_github_script_function,
+            )
+
+            with load_script("path/to/script.py") as module:
+                return run_github_script_function(module, token, 60.0, args)
     """
     if not hasattr(module, GITHUB_SCRIPT_FUNCTION_NAME):
         raise GitHubScriptError(
@@ -86,7 +108,7 @@ def run_github_script_function(
         )
 
     async def run_async() -> int:
-        async with GitHubAsyncRESTApi(token, timeout=timeout) as api:
+        async with GitHubAsyncRESTApi(token, timeout=Timeout(timeout)) as api:
             return await func(api, args)
 
     loop_owner = False
@@ -109,12 +131,27 @@ def run_add_arguments_function(
     module: ModuleType, parser: ArgumentParser
 ) -> None:
     """
-    Run a GitHub script add_script_arguments function
+    Run a GitHub script add_script_arguments function (if available in the
+    module).
 
     Args:
         module: Module containing the GitHub script add_script_arguments
             function
         parser: An ArgumentParser to add additional CLI arguments
+
+    Example:
+        .. code-block:: python
+
+            from argparse import ArgumentParser
+            from pontos.github.script import (
+                load_script,
+                run_github_script_function,
+            )
+
+            parser = ArgumentParser()
+
+            with load_script("path/to/script.py") as module:
+                run_add_arguments_function(module, parser)
     """
     func = getattr(module, GITHUB_SCRIPT_PARSER_FUNCTION_NAME, None)
     if func:
