@@ -66,12 +66,12 @@ class ReleaseCommand:
 
     def _get_release_version(
         self,
-        project: Project,
+        *,
+        current_version: Version,
         calculator: VersionCalculator,
         release_type: ReleaseType,
         release_version: Optional[Version],
     ) -> Version:
-        current_version = project.get_current_version()
         if release_type == ReleaseType.CALENDAR:
             return calculator.next_calendar_version(current_version)
 
@@ -198,8 +198,15 @@ class ReleaseCommand:
         calculator = versioning_scheme.calculator()
 
         try:
+            current_version = project.get_current_version()
+
+            self.terminal.info(f"Current version is {current_version}")
+
             release_version = self._get_release_version(
-                project, calculator, release_type, release_version
+                current_version=current_version,
+                calculator=calculator,
+                release_type=release_type,
+                release_version=release_version,
             )
         except VersionError as e:
             self.terminal.error(f"Unable to determine release version. {e}")
@@ -230,10 +237,21 @@ class ReleaseCommand:
             )
             return ReleaseReturnValue.UPDATE_VERSION_ERROR
 
+        if release_type == ReleaseType.PATCH:
+            tag_name = (
+                f"{self.git_tag_prefix}"
+                f"{release_version.major}.{release_version.minor}.*"
+            )
+        elif release_type == ReleaseType.MINOR:
+            tag_name = f"{self.git_tag_prefix}{release_version.major}.*"
+        else:
+            tag_name = None
+
         last_release_version = get_last_release_version(
             calculator.version_from_string,
             git_tag_prefix=self.git_tag_prefix,
             ignore_pre_releases=not release_version.is_pre_release,
+            tag_name=tag_name,
         )
 
         self.terminal.info(
