@@ -20,6 +20,7 @@
 from typing import Optional
 
 from pontos.git import Git, TagSort
+from pontos.git.git import DEFAULT_TAG_SORT_SUFFIX
 
 from .version import ParseVersionFuncType, Version
 
@@ -29,6 +30,7 @@ def get_last_release_version(
     *,
     git_tag_prefix: Optional[str] = "",
     ignore_pre_releases: Optional[bool] = False,
+    tag_name: Optional[str] = None,
 ) -> Optional[Version]:
     """Get the last released Version from git.
 
@@ -36,13 +38,18 @@ def get_last_release_version(
         git_tag_prefix: Git tag prefix to consider
         ignore_pre_release: Ignore pre releases and only consider non pre
             releases. Default is False.
+        tag_name: A pattern for filtering the tags. For example: "1.2.*"
 
     Returns:
-        Last released git-tag as Version if tags were found
+        Last released git tag as Version if tags were found
         or None
     """
 
-    tag_list = Git().list_tags(sort=TagSort.VERSION)
+    tag_list = Git().list_tags(
+        sort=TagSort.VERSION,
+        sort_suffix=DEFAULT_TAG_SORT_SUFFIX,
+        tag_name=tag_name,
+    )
 
     while tag_list:
         last_release_version = tag_list[-1]
